==> antco-0.1.3.tar.gz: antco-0.1.3/setup.py <==
from setuptools import find_packages, setup
import numpy
from Cython.Build import cythonize


with open("README.md", 'r') as f:
    long_description = f.read()


# python setup.py build_ext -i
setup(name='antco',
      version='0.1.3',
      license='BSD3',
      description='Ant Colony Optimization framework',
      author='Fernando García Gutiérrez',
      author_email='fegarc05@ucm.es',
      url='https://github.com/FernandoGaGu/Ant-Colony-Optimisation/',                           
      download_url='https://github.com/FernandoGaGu/Ant-Colony-Optimisation/archive/refs/tags/0.1.tar.gz',
      install_requires=[
                'numpy', 
                'joblib', 
                'cython', 
                'matplotlib', 
                'deap', 
                'seaborn', 
                'networkx'
            ],
      keywords=['Optimisation', 'Ant Colony Optimisation', 'Metaheuristic', 'Algorithms'],
      packages=find_packages(),
      ext_modules=cythonize([
                'antco/c_metrics.pyx', 
                'antco/c_ntools.pyx',
                'antco/c_pheromone.pyx',
                'antco/c_policy.pyx',
                'antco/c_utils.pyx']),
      include_dirs=[numpy.get_include()],
      classifiers=[
          'Development Status :: 4 - Beta',
          'Intended Audience :: Developers',
          'Topic :: Software Development :: Build Tools',
          'License :: OSI Approved :: BSD License', 
          'Programming Language :: Python :: 3', 
          'Programming Language :: Python :: 3.4', 
          'Programming Language :: Python :: 3.5',
          'Programming Language :: Python :: 3.6',
          'Programming Language :: Python :: 3.7',],
      )

==> antco-0.1.5.tar.gz: antco-0.1.5/setup.py <==
from setuptools import find_packages, setup
import numpy
from Cython.Build import cythonize


with open("README.md", 'r') as f:
    long_description = f.read()


# python setup.py build_ext -i
setup(name='antco',
      version='0.1.5',
      license='BSD3',
      description='Ant Colony Optimization framework',
      author='Fernando García Gutiérrez',
      author_email='fegarc05@ucm.es',
      url='https://github.com/FernandoGaGu/Ant-Colony-Optimisation/',                           
      download_url='https://github.com/FernandoGaGu/Ant-Colony-Optimisation/archive/refs/tags/0.1.tar.gz',
      install_requires=[
                'numpy', 
                'joblib', 
                'cython', 
                'matplotlib', 
                'deap', 
                'seaborn', 
                'networkx'
            ],
      keywords=['Optimisation', 'Ant Colony Optimisation', 'Metaheuristic', 'Algorithms'],
      packages=find_packages(),
      ext_modules=cythonize([
                './antco/c_metrics.pyx', 
                './antco/c_ntools.pyx',
                './antco/c_pheromone.pyx',
                './antco/c_policy.pyx',
                './antco/c_utils.pyx']),
      include_dirs=[numpy.get_include()],
      classifiers=[
          'Development Status :: 4 - Beta',
          'Intended Audience :: Developers',
          'Topic :: Software Development :: Build Tools',
          'License :: OSI Approved :: BSD License', 
          'Programming Language :: Python :: 3', 
          'Programming Language :: Python :: 3.4', 
          'Programming Language :: Python :: 3.5',
          'Programming Language :: Python :: 3.6',
          'Programming Language :: Python :: 3.7',],
      )
